pub struct Commander { /* private fields */ }
Commander allows you to start localnet, build programs, run tests and do other useful operations.

Implementations

Creates a new Commander instance with the default root "../../".

Creates a new Commander instance with the provided root.

Builds programs (smart contracts).

Runs standard Rust tests.

Note: The –nocapture argument is used to allow you read println outputs in your terminal window.

Creates the program_client crate.

It’s used internally by the #[trdelnik_test] macro.

Returns an Iterator of program Packages read from Cargo.toml files.

Updates the program_client dependencies.

It’s used internally by the #[trdelnik_test] macro.

Updates the program_client lib.rs.

It’s used internally by the #[trdelnik_test] macro.

Formats program code.

Starts the localnet (Solana validator).