Struct trdelnik_client::LocalnetHandle
source · [−]pub struct LocalnetHandle { /* private fields */ }Expand description
Localnet (the validator process) handle.
Implementations
sourceimpl LocalnetHandle
impl LocalnetHandle
sourcepub async fn stop(self) -> Result<(), Error>
pub async fn stop(self) -> Result<(), Error>
Stops the localnet.
Note: Manual kill: kill -9 $(lsof -t -i:8899)
Errors
It fails when:
- killing the process failed.
- process is still running after the kill command has been performed.
sourcepub async fn stop_and_remove_ledger(self) -> Result<(), Error>
pub async fn stop_and_remove_ledger(self) -> Result<(), Error>
Stops the localnet and removes the ledger.
Note: Manual kill: kill -9 $(lsof -t -i:8899)
Errors
It fails when:
- killing the process failed.
- process is still running after the kill command has been performed.
- cannot remove localnet data (the
test-ledgerdirectory).