pub struct Reader { /* private fields */ }
Reader allows you to read Pubkey, Keypair and other entities from files.

Implementations

Creates a new Reader instance with the default root "../../".

Creates a new Reader instance with the provided root.

Reads Pubkey from [root]keys/[name]_pub.json.

Errors

It fails when:

  • the requested file does not exist or it is not readable.
  • Pubkey cannot be parsed from the file content.

Reads Keypair from [root]keys/[name].json.

Errors

It fails when:

  • the requested file does not exist or it is not readable.
  • Keypair cannot be parsed from the file content.

Reads program data from [root]target/deploy/[name].so.

Errors

It fails when the requested file does not exist or it is not readable.