pub struct TestGenerator;

Implementations

Builds all the programs and creates .program_client directory. Initializes the trdelnik-tests/tests directory with all the necessary files. Adds the test.rs file and generates Cargo.toml with dev-dependencies. Updates root’s Cargo.toml workspace members.

The crate is generated from trdelnik-tests template located in client/src/templates.

Before you start writing trdelnik tests do not forget to add your program as a dependency to the trdelnik-tests/Cargo.toml. For example:

[dev-dependencies]
my-program = { path = "../programs/my-program" }

Then you can easily use it in tests:

use my_program;

// ...

#[trdelnik_test]
async fn test() {
    // ...
    my_program::do_something(/*...*/);
    // ...
}
Errors

It fails when:

  • there is not a root directory (no Anchor.toml file)