Trait trdelnik_client::ToAccountMetas
[−]pub trait ToAccountMetas {
fn to_account_metas(
&self,
is_signer: Option<bool>
) -> Vec<AccountMeta, Global>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator, ;
}Expand description
Transformation to
AccountMeta
structs.
Required Methods
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.